###########################################################
### Ch6 - Script 1 - Load Data
###########################################################

###########################################################
### Packages
###########################################################
library(here)
library(tidyverse)
library(ggridges)
library(GThomsonThesis)
library(ggpubr)

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Data
###########################################################

# Load reads counts at different preprocessing steps
raw_data_read_dist <- here("Data/raw_data_read_dist.txt") %>% 
  read_delim(" ", escape_double = FALSE, trim_ws = TRUE, col_types = cols()) %>% 
  mutate(lib = str_sub(lib, 10, 20))

adpt_data_read_dist <- here("Data/adpt_trim_read_dist.txt") %>% 
  read_delim(" ", escape_double = FALSE, trim_ws = TRUE, col_types = cols()) %>% 
  mutate(lib = str_sub(lib, 16, 26))

qual_data_read_dist <- here("Data/qual_trim_read_dist.txt") %>% 
  read_delim(" ", escape_double = FALSE, trim_ws = TRUE, col_types = cols()) %>% 
  mutate(lib = str_sub(lib, 16, 26))

# Load mapping rate
mapping_rate <- here("Data/mapping_rate.csv") %>%  
  read_csv(col_names = FALSE, col_types = cols()) %>% 
  select(sample = X1, rate = X2)

###########################################################
### Preprocessing graphs
###########################################################
labels <- setNames(
  adpt_data_read_dist %>% 
    pull(lib) %>% 
    unique() %>% 
    ifelse(grepl("R1",.), .,  " ") %>% 
    str_sub(1, 8) %>% 
    str_replace("_", " ") %>% 
    str_replace("_", " #"),
  adpt_data_read_dist %>% 
    pull(lib) %>% 
    unique()
)

# Size of reads
size_of_reads <- 
  adpt_data_read_dist %>% 
  mutate(treat = "adpt") %>% 
  bind_rows(qual_data_read_dist %>% 
              mutate(treat = "qual")) %>%  
  mutate(lib = factor(lib)) %>% 
  ggplot(aes(len, forcats::fct_rev(lib), fill = treat)) +
  geom_density_ridges(scale = 2, alpha = 0.6, colour = "white") +
  scale_x_continuous(expand = c(0.01, 0)) +
  scale_y_discrete(expand = c(0.0, 0), labels = labels) +
  scale_fill_manual(values = g_colours[c(8, 3)],
                    labels=c("Adaptor trimming", "Quality and length trimming")) +
  labs(x="Read length") +
  theme(axis.title.x = element_text(size = 16, face = "bold", vjust = -2),
        axis.text.x = element_text(size = 14, face = "bold"),
        axis.title.y = element_blank(),
        axis.text.y = element_text(size=12),
        legend.title=element_blank(),
        legend.position="bottom")

# Number of reads
number_of_reads <- raw_data_read_dist %>% 
  transmute(lib = lib, raw = count) %>% 
  left_join(adpt_data_read_dist %>% 
              group_by(lib) %>% 
              summarise(adpt = sum(count))) %>% 
  left_join(qual_data_read_dist %>%
              group_by(lib) %>% 
              summarise(qual = sum(count))) %>% 
  mutate(raw = raw - adpt, 
         adpt = adpt - qual) %>% 
  gather(treatment, count, -lib) %>% 
  mutate(lib = str_sub(lib, 0, 8),
         treatment = factor(treatment, levels = c("raw", "adpt", "qual"))) %>% 
  distinct() %>% 
  ggplot(aes(lib, count, fill = treatment)) +
  geom_col() +
  scale_y_continuous(expand = c(0.0, 0)) +
  scale_fill_manual(values = g_colours[c(4,2,3)],
                    labels=c("Raw data", "Adaptor trimming", "Quality and length trimming")) +
  labs(y="Number of reads") +
  theme(
    axis.text.x = element_blank(),
    axis.title.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.y = element_text(size = 16, face = "bold"),
    axis.text.y = element_text(size=12),
    legend.title=element_blank(),
    legend.position="bottom")

ggarrange(size_of_reads, 
          ggarrange(number_of_reads + rremove("x.text"), NULL, nrow = 2, labels = c("B", ""), align = "v"), 
          ncol = 2,
          labels = c("A"))

ggsave("Ch6_Preprocessing_and_exploratory_analysis.png", width = 290, height = 225, units = "mm")

###########################################################
### Mean mapping rate
###########################################################
mapping_rate %>% 
  pull(rate) %>% 
  summary()
